@@ -1,9 +1,9 @@
 is_mac <- function() {
-  return(grepl('darwin', R.Version()$platform, ignore.case = TRUE) && grepl('x86', R.Version()$platform, ignore.case = TRUE))
+  return(grepl('darwin', R.Version()$platform, ignore.case = TRUE))
 }
 
 skip_if_not_mac <- function() {
-  if(is_mac()) {
+  if(is_mac() && R.version[["arch"]] != "aarch64") {
     return(invisible(TRUE))
   }
 
