@@ -10,9 +10,6 @@ test_that("Tests if imputation splitting works", {
 
   rf <- forestry(x = x,
                  y = y,
-                 nthread = 2,
-                 seed=239,
-                 scale=FALSE,
                  ntree = 500)
 
   pred <- predict(rf, x)
@@ -21,7 +18,6 @@ test_that("Tests if imputation splitting works", {
 
   rf_impute <- forestry(x = x_missing,
                         y = y,
-                        nthread = 2,
                         ntree = 500)
 
   pred_na <- predict(rf_impute, x)
@@ -49,7 +45,6 @@ test_that("Tests if imputation splitting works", {
 
   rf <- forestry(x = x,
                  y = y,
-                 nthread = 2,
                  ntree = 500)
 
   pred <- predict(rf, x)
@@ -59,7 +54,6 @@ test_that("Tests if imputation splitting works", {
 
   rf_impute <- forestry(x = x_missing,
                         y = y,
-                        nthread = 2,
                         ntree = 500)
 
   pred_na <- predict(rf_impute, x)
