@@ -3,7 +3,7 @@ test_that("Tests that terminal nodes are correct", {
   y <- iris[, 1]
 
   context('Terminal nodes')
-  # Set seed for reproducibility
+  # Set seed for reproductivity
   set.seed(24750371)
 
   # Test forestry (mimic RF)
@@ -12,14 +12,12 @@ test_that("Tests that terminal nodes are correct", {
     x,
     y,
     replace = TRUE,
-    nthread = 2,
-    maxDepth = 5,
-    seed = 2323
+    maxDepth = 5
   )
 
   skip_if_not_mac()
 
   # Test predict
-  full_predictions <- predict(forest, x[c(5, 100, 104),], aggregation = 'terminalNodes')$terminalNodes
-  expect_equal(full_predictions, matrix(c(1, 8, 15, 23), ncol = 1))
+  full_predictions <- predict(forest, x[c(5, 100, 104),], aggregation = 'weightMatrix')$terminalNodes
+  expect_equal(full_predictions, matrix(c(5,14,14,19), ncol = 1))
 })
